@@ -964,6 +964,15 @@ static void test_oneof_SubMess (void)
   DO_TEST (&submess, test_optional_submess_42);
 #undef DO_TEST
 }
+
+static void test_oneof_message_check(void)
+{
+	Foo__TestMessOneof msg = FOO__TEST_MESS_ONEOF__INIT;
+	msg.test_oneof_case = FOO__TEST_MESS_ONEOF__TEST_ONEOF_TEST_STRING;
+	msg.test_string = "Hello, world!";
+	assert(protobuf_c_message_check((ProtobufCMessage *)&msg));
+}
+
 static void test_oneof_merge (void)
 {
   Foo__TestMessOneof *msg;
@@ -1674,7 +1683,7 @@ assert_required_default_values_are_default (Foo__DefaultRequiredValues *mess)
   assert (mess->v_float == 2.5);
   assert (mess->v_double == 4.5);
   assert (strcmp (mess->v_string, "hi mom\n") == 0);
-  assert (mess->v_bytes.len = /* a */ 1
+  assert (mess->v_bytes.len == /* a */ 1
                                + /* space */ 1
                                + /* NUL */ 1
                                + /* space */ 1
@@ -1713,7 +1722,7 @@ assert_optional_default_values_are_default (Foo__DefaultOptionalValues *mess)
   assert (mess->v_double == 4.5);
   assert (strcmp (mess->v_string, "hi mom\n") == 0);
   assert (!mess->has_v_bytes);
-  assert (mess->v_bytes.len = /* a */ 1
+  assert (mess->v_bytes.len == /* a */ 1
                                + /* space */ 1
                                + /* NUL */ 1
                                + /* space */ 1
@@ -1721,6 +1730,33 @@ assert_optional_default_values_are_default (Foo__DefaultOptionalValues *mess)
   assert (memcmp (mess->v_bytes.data, "a \0 character", 13) == 0);
 }
 
+static void
+assert_unspecified_default_values_are_correct (Foo__TestMessOptional *mess)
+{
+  assert (!mess->has_test_int32);
+  assert (mess->test_int32 == 0);
+  assert (!mess->has_test_uint32);
+  assert (mess->test_uint32 == 0);
+  assert (!mess->has_test_int64);
+  assert (mess->test_int64 == 0);
+  assert (!mess->has_test_uint64);
+  assert (mess->test_uint64 == 0);
+  assert (!mess->has_test_float);
+  assert (mess->test_float == 0.0);
+  assert (!mess->has_test_double);
+  assert (mess->test_double == 0.0);
+  assert (mess->test_string == NULL);
+  assert (!mess->has_test_bytes);
+  assert (mess->test_bytes.len == 0);
+  assert (mess->test_bytes.data == NULL);
+  assert (!mess->has_test_boolean);
+  assert (!mess->test_boolean);
+  assert (!mess->has_test_enum_small);
+  assert (mess->test_enum_small == FOO__TEST_ENUM_SMALL__NEG_VALUE);
+  assert (!mess->has_test_enum);
+  assert (mess->test_enum == FOO__TEST_ENUM__VALUENEG123456);
+}
+
 static void
 test_optional_default_values (void)
 {
@@ -1733,6 +1769,9 @@ test_optional_default_values (void)
   free (data);
   assert_optional_default_values_are_default (mess2);
   foo__default_optional_values__free_unpacked (mess2, NULL);
+
+  Foo__TestMessOptional mess3 = FOO__TEST_MESS_OPTIONAL__INIT;
+  assert_unspecified_default_values_are_correct (&mess3);
 }
 
 static void
@@ -2151,6 +2190,12 @@ test_message_check(void)
   assert(1 == protobuf_c_message_check(&m.base));
 }
 
+static void
+test_message_free_null (void)
+{
+  foo__sub_mess__free_unpacked (NULL, NULL);
+}
+
 /* === simple testing framework === */
 
 typedef void (*TestFunc) (void);
@@ -2224,6 +2269,7 @@ static Test tests[] =
   { "test oneof string", test_oneof_string },
   { "test oneof bytes", test_oneof_bytes },
   { "test oneof SubMess", test_oneof_SubMess },
+  { "test oneof message check", test_oneof_message_check },
   { "test merged oneof unpack", test_oneof_merge },
 
   { "test empty repeated" ,test_empty_repeated },
@@ -2286,6 +2332,8 @@ static Test tests[] =
   { "test field flags", test_field_flags },
 
   { "test message_check()", test_message_check },
+
+  { "test freeing NULL", test_message_free_null },
 };
 #define n_tests (sizeof(tests)/sizeof(Test))
 
